/*
 * Copyright (c) 2002 Sandro Sigala.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <fx.h>

#include "fxreptoned.h"
#include "map.h"

class MapWindow;

class MainWindow: public FXMainWindow {
    	FXDECLARE(MainWindow)

private:
       	FXXPMIcon *bigicon, *smallicon;
       	FXMenuPane *filemenu, *windowmenu, *helpmenu;
   	MapWindow *mapw;
//    	SpriteWindow *spritew;
 	Episode episode;
	FXBMPImage *sprites[num_sprites];
	FXLabel *shortname_label;
	FXTextField *pkg_edit, *name_edit, *author_edit, *cmt_edit;

	bool save(bool saveas);
	bool saveIfChanged();
	FXString chooseEpisode(const vector<Episode>& v, bool templ = false, bool *incmaps = 0);
	void updateTitle();
	void updateFields();
	void loadSprites(const FXString& spritespath);
	void saveSprites(const FXString& spritespath);
	bool strictCheckTransporters(int no, Map *m);
	bool strictCheck(bool showok);

protected:
	MainWindow();

private:
  	MainWindow(const MainWindow&);
  	MainWindow& operator =(const MainWindow&);

public:
	long onCmdNew		(FXObject *, FXSelector, void *);
	long onCmdOpen		(FXObject *, FXSelector, void *);
	long onCmdSave		(FXObject *, FXSelector, void *);
	long onUpdSave		(FXObject *, FXSelector, void *);
	long onCmdSaveAs	(FXObject *, FXSelector, void *);
	long onUpdSaveAs	(FXObject *, FXSelector, void *);
	long onCmdSCheck	(FXObject *, FXSelector, void *);
	long onUpdSCheck	(FXObject *, FXSelector, void *);
	long onCmdQuit		(FXObject *, FXSelector, void *);
	long onCmdMaps		(FXObject *, FXSelector, void *);
	long onUpdMaps		(FXObject *, FXSelector, void *);
	long onCmdSprites	(FXObject *, FXSelector, void *);
	long onUpdSprites	(FXObject *, FXSelector, void *);
    	long onCmdAbout		(FXObject *, FXSelector, void *);
	long onCmdInfoChange	(FXObject *, FXSelector, void *);

public:
    	enum {
            	ID_QUIT = FXMainWindow::ID_LAST,
            	ID_NEW,
             	ID_OPEN,
             	ID_SAVE,
             	ID_SAVEAS,
             	ID_SCHECK,
            	ID_MAPS,
            	ID_SPRITES,
            	ID_ABOUT,
            	ID_SECTION,
            	ID_NAME,
             	ID_AUTHOR,
              	ID_COMMENT,
            	ID_LAST
    	};

public:
	MainWindow(FXApp *app);
	~MainWindow();

  	virtual void create();
};

#endif // MAINWINDOW_H

