/*
 * Copyright (c) 2002 Sandro Sigala.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MAPWINDOW_H
#define MAPWINDOW_H

#include <fx.h>

#include "fxreptoned.h"

class Episode;
class MapViewer;

class MapWindow: public FXTopWindow {
    	FXDECLARE(MapWindow)

private:
	FXBMPImage **sprites;
	FXBMPImage *tools;
	FXImageView *toolsview;
	MapViewer *mapview;
	Sprite currenttool;
	FXList *maps_list, *trans_list;
	FXTextField *name_edit, *cmt_edit, *pwd_edit, *time_edit;
	FXCheckButton *readonly_check;
	FXButton *map_ins, *map_dup, *map_rsz, *map_del, *map_up, *map_down;
	FXButton *trans_del, *trans_chg;
	FXLabel *pos_label;
	FXLabel *mapsize_label;
	Episode *episode;
	int currentmap;

	void redrawTools();
	void redrawMap();
	void updateMapsList();
	void updateTransList();
	void updateButtons();

protected:
	MapWindow();

private:
  	MapWindow(const MapWindow&);
  	MapWindow& operator =(const MapWindow&);

public:
	long onToolsMouseUp	(FXObject *, FXSelector, void *);
	long onMapChange	(FXObject *, FXSelector, void *);
	long onMapMouseMove	(FXObject *, FXSelector, void *);
	long onMapListChange	(FXObject *, FXSelector, void *);
	long onCmdMapInsert	(FXObject *, FXSelector, void *);
	long onCmdMapDuplicate	(FXObject *, FXSelector, void *);
	long onCmdMapResize	(FXObject *, FXSelector, void *);
	long onCmdMapDelete	(FXObject *, FXSelector, void *);
	long onCmdMapUp		(FXObject *, FXSelector, void *);
	long onCmdMapDown	(FXObject *, FXSelector, void *);
	long onCmdTransChange	(FXObject *, FXSelector, void *);
	long onCmdTransDelete	(FXObject *, FXSelector, void *);
	long onCmdInfoChange	(FXObject *, FXSelector, void *);

public:
	enum {
    		ID_TOOLS = FXTopWindow::ID_LAST,
    		ID_MAP,
    		ID_MAPSLIST,
    		ID_MAPINS,
    		ID_MAPDUP,
    		ID_MAPRSZ,
    		ID_MAPDEL,
    		ID_MAPUP,
    		ID_MAPDOWN,
    		ID_TRANSLIST,
    		ID_TRANSCHG,
    		ID_TRANSDEL,
    		ID_READONLY,
    		ID_PWD,
    		ID_COMMENT,
    		ID_TIME,
    		ID_LAST
	};

public:
  	MapWindow(FXApp *a, const FXString& name, Episode *e, FXBMPImage **s, FXIcon *icon, FXIcon *miniicon);
	~MapWindow();

	virtual void create();

	void selectMap(int no);
	void spritesChanged();

};

#endif // MAPWINDOW_H

